@@ -7,7 +7,9 @@ import redis
 from copy import deepcopy
 from typing import Callable
 
+from asgiref.sync import sync_to_async
 from django.db import models as django_models
+from django.db.models.query_utils import DeferredAttribute
 
 from .utils import check_types, check_classes, get_ids_from_untyped_data
 from .cache import default_cache_func, django_sync_to_async_list, django_sync_to_async_get
@@ -786,8 +788,6 @@ class RedisRoot:
 
         return cache_conf
 
-
-
     async def update_or_create_redis_instance_from_django_instance(
             self,
             django_instance,
@@ -868,6 +868,10 @@ class RedisRoot:
 
         return redis_params
 
+    @sync_to_async
+    def sync_to_async_deferred_attribute_value(self, django_field_value):
+        return django_field_value.__get__()
+
     async def django_instance_field_to_redis_value(
             self,
             django_instance,
@@ -877,6 +881,8 @@ class RedisRoot:
 
         save_related_models = cache_conf['save_related_models']
         django_field_value = await django_sync_to_async_get(django_instance, django_field.name)
+        if isinstance(django_field_value, DeferredAttribute):
+            django_field_value = await sync_to_async_deferred_attribute_value(django_field_value)
         redis_value = django_field_value
         if django_field.__class__ == django_models.ForeignKey:
             if django_field_value is None:
@@ -1113,16 +1119,23 @@ class RedisRoot:
 
     def _filter(self, value, fields_to_filter, filter_type, filter_by):
         for field_to_filter in fields_to_filter:
-            try:
-                value = value[field_to_filter]
-            except KeyError as ex:
-                raise Exception(f'KeyError: {ex}\n'
-                                f'Info: {field_to_filter}, {value}\n'
-                                f'Maybe: deep filtering is not included on this model')
+            if value in ['null', None]:
+                value = None
+            else:
+                try:
+                    value = value[field_to_filter]
+                except BaseException as ex:
+                    print(f'Exception: {ex}\n'
+                          f'Info: {field_to_filter}, {value}\n'
+                          f'Maybe: deep filtering is not included on this model')
+                    value = None
         if isinstance(value, datetime.datetime) and isinstance(filter_by, datetime.datetime):
             value = value.replace(tzinfo=pytz.UTC)
             filter_by = filter_by.replace(tzinfo=pytz.UTC)
-        allowed = self._filter_value(value, filter_type, filter_by)
+        try:
+            allowed = self._filter_value(value, filter_type, filter_by)
+        except:
+            allowed = False
         return allowed
 
     def _filter_field_name(self, redis_model, field_name, value, raw_filters):
@@ -1247,12 +1260,14 @@ class RedisRoot:
             }
         return updated_data
 
-    def _get_allowed_redis_model_params(self, params, redis_model):
+    def _get_allowed_redis_model_params(self, redis_model, params):
         redis_model_fields_names = redis_model.__dict__.keys()
-        result_params = list(filter(
+        allowed_param_names = list(filter(
             lambda param_name: param_name in redis_model_fields_names and not param_name.startswith('__'),
             params.keys()
         ))
+        result_params = {param_name: params[param_name] for param_name in params.keys() if
+                         param_name in allowed_param_names}
         return result_params
 
     def update(self, django_model, instances=None, return_dict=False, renew_ttl=False, new_ttl=None,
@@ -1470,5 +1485,3 @@ class RedisModel:
             return meta[field_name]
         else:
             raise Exception(f'{name} has no field {field_name}')
-
-
